@@ -7,8 +7,7 @@ void IntegrityScanner::read(Process &src, string const &fname)
     ofstream target(fname.c_str());
 
     if (!target)
-        d_stealthLog << "Can't open `" << fname << "' to write" <<
-                                                        StealthEnums::leave; 
+        fmsg << "can't write `" << fname << '\'' << noidl; 
 
     char c;
     string partialSentinel;
@@ -18,13 +17,8 @@ void IntegrityScanner::read(Process &src, string const &fname)
 
     while (true)
     {
-        if (!src.read(&c, 1))               // read char by char
-        {
-            d_run.setMode(RunMode::TERMINATE);
-            d_stealthLog << "Incomplete read from `" << fname << "'" <<
-                                                            StealthEnums::leave; 
-            return;
-        }
+        if (not src.read(&c, 1))            // read char by char
+            fmsg << "Incomplete read from `" << fname << "'" << noidl; 
 
         checkSize(fname, ++size);           // throws if not OK
 
