@@ -8,6 +8,8 @@ void Options::setTimestamp()
 
     if (value == "LT")
         d_timestamp = TIMESTAMPS;
+    else if (value == "UTC")
+        d_timestamp = UTCTIMESTAMPS;
     else if (value != "UTC")
         wmsg << "--time-stamp " << value << " not supported. Using UTC" <<
                                                                     endl;
